#
# spec file for package agama-cli
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           agama-cli
#               This will be set by osc services, that will run after this.
Version:        7
Release:        5.2
Summary:        Agama command line interface
#               If you know the license, put it's SPDX string here.
#               Alternately, you can use cargo lock2rpmprovides to help generate this.
License:        GPL-2.0-only
URL:            https://github.com/opensuse/agama
Source0:        agama.tar
Source1:        vendor.tar.zst
# Generated by the cargo_vendor OBS service
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(openssl)
# used in tests for dbus service
BuildRequires:  python-langtable-data
BuildRequires:  dbus-1-common
BuildRequires:  timezone
# required by agama-dbus-server integration tests
BuildRequires:  dbus-1-daemon
Requires:       jsonnet
Requires:       lshw
# required by "agama logs store"
Requires:       bzip2
Requires:       tar
# required for translating the keyboards descriptions
Requires:       xkeyboard-config-lang
# required for getting the list of timezones
Requires:       timezone

%description
Command line program to interact with the agama service.

%package -n agama-dbus-server
#               This will be set by osc services, that will run after this.
Version:        7
Release:        5.2
Summary:        Agama Rust D-Bus service
License:        GPL-2.0-only
URL:            https://github.com/opensuse/agama
Requires:       dbus-1-common
Requires:       python-langtable-data

%description -n agama-dbus-server
DBus service for agama project. It provides so far localization service.

%prep
%autosetup -a1 -n agama
mkdir .cargo
cp %{SOURCE2} .cargo/config
# Remove exec bits to prevent an issue in fedora shebang checking. Uncomment only if required.
# find vendor -type f -name \*.rs -exec chmod -x '{}' \;

%build
%{cargo_build}

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/agama/target/release/agama %{buildroot}%{_bindir}/agama
install -m 0755 %{_builddir}/agama/target/release/agama-dbus-server %{buildroot}%{_bindir}/agama-dbus-server
install -D -d -m 0755 %{buildroot}%{_datadir}/agama-cli
install -m 0644 %{_builddir}/agama/agama-lib/share/profile.schema.json %{buildroot}%{_datadir}/agama-cli
install --directory %{buildroot}%{_datadir}/dbus-1/agama-services
install -m 0644 --target-directory=%{buildroot}%{_datadir}/dbus-1/agama-services %{_builddir}/agama/share/*.service

%check
%ifarch aarch64
/usr/bin/cargo auditable test -j1 --offline --no-fail-fast
%else
%{cargo_test}
%endif

%files
%{_bindir}/agama
%dir %{_datadir}/agama-cli
%{_datadir}/agama-cli/profile.schema.json

%files -n agama-dbus-server
%{_bindir}/agama-dbus-server
%{_datadir}/dbus-1/agama-services

%changelog
* Thu Dec 21 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 7
* Thu Dec 21 2023 Ancor Gonzalez Sosa <ancor@suse.com>
- The result of ListTimezones includes the localized country name
  for each timezone (gh#openSUSE/agama#946)
* Fri Dec 15 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update agama-cli dependencies including the zerocopy crate to
  address a security alert (see gh#google/zerocopy#716).
* Wed Dec 13 2023 Knut Anderssen <kanderssen@suse.com>
- Add support for bonding connections (gh#openSUSE/agama#885).
* Fri Dec  8 2023 Josef Reidinger <jreidinger@suse.com>
- Change the config in a way that: (gh#openSUSE/agama#919)
  1. product is moved to own section and is now under product.id
  2. in product section is now also registrationCode and registrationEmail
  3. in software section is now patterns to select patterns to install
- adapt profile.schema according to above changes
- org.opensuse.Agama.Software1 API changed to report missing patterns
* Tue Dec  5 2023 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add ability to assign a custom MAC address for network
  connections (gh#openSUSE/agama#893)
* Tue Dec  5 2023 José Iván López González <jlopez@suse.com>
- Explicitly add dependencies instead of relying on the live ISO
  to provide the required packages (gh#openSUSE/agama/911).
* Tue Dec  5 2023 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add support for dummy network devices although they are not
  exposed on D-Bus yet (gh#openSUSE/agama#913).
* Sun Dec  3 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use a single call to systemd-firstboot to write the localization
  settings (gh#openSUSE/agama#903).
* Sat Dec  2 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 6
* Wed Nov 29 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Rework the org.opensuse.Agama1.Locale interface
  (gh#openSUSE/agama#881):
  * Replace LabelsForLocales function with ListLocales.
  * Add a ListKeymaps function.
  * Extend the ListTimezone function to include the translation of
    each part.
  * Drop ListUILocales and ListVConsoleKeyboards functions.
  * Remove the SupportedLocales and VConsoleKeyboard properties.
  * Do not read the lists of locales, keymaps and timezones on
    each request.
  * Peform some validation when trying to change the Locales,
    Keymap and Timezone properties.
* Thu Nov 16 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update dependencies to compatible versions
  (gh#openSUSE/agama#874).
- Replace tempdir with tempfile to prevent RUSTSEC-2023-0018.
* Wed Nov 15 2023 José Iván López González <jlopez@suse.com>
- Adapt to changes in software D-Bus API (gh#openSUSE/agama#869).
* Wed Nov 15 2023 Michal Filka <mfilka@suse.com>
- Improved "agama logs store" (gh#openSUSE/agama#823)
  - added an option which allows to define the archive destination
* Tue Nov 14 2023 Jorik Cronenberg <jorik.cronenberg@suse.com>
- Add support for routing to the network model (gh#openSUSE/agama#824)
* Mon Oct 23 2023 Michal Filka <mfilka@suse.com>
- Improved "agama logs store" (gh#openSUSE/agama#812)
  - the archive file owner is root:root
  - the permissions is set to r/w for the owner
* Mon Oct 23 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 5
* Tue Oct 10 2023 Michal Filka <mfilka@suse.com>
- Improve file and directory names in "agama logs store".
- Add an "agama logs list" subcommand.
* Tue Sep 26 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 4
* Tue Sep 26 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Wait until the manager is ready before probing
  (gh#openSUSE/agama#771).
* Mon Sep 25 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for IPv6 network settings (gh#openSUSE/agama#761).
* Mon Sep 25 2023 Michal Filka <mfilka@suse.com>
- CLI: added (sub)commands for handling logs. "store" subcommand is
  similar to what old save_y2logs did. (gh#openSUSE/agama#757)
* Tue Sep 19 2023 José Iván López González <jlopez@suse.com>
- Adapt to new storage D-Bus API and explicitly call to probe after
  selecting a new product (gh#openSUSE/agama#748).
* Thu Sep 14 2023 Josef Reidinger <jreidinger@suse.com>
- Improve questions CLI help text (gh#openSUSE/agama#754)
* Thu Sep 14 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use a single D-Bus service to connect to the manager and the
  users API (gh#openSUSE/agama#753, follow-up of
  gh#openSUSE/agama#729).
* Wed Sep 13 2023 Knut Anderssen <kanderssen@suse.com>
- Allow to bind a connection to an specific interface through its
  name or through a set of match settings (gh#opensSUSE/agama#723).
* Thu Aug 31 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use a single D-Bus service to expose locale, network and
  questions settings (gh#openSUSE/agama#729).
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.com>
- Locale service: add value for UI locale (gh#openSUSE/agama#725)
* Thu Aug  3 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Move the settings functionality to a separate package,
  agama-settings (gh#openSUSE/agama#666).
- Make the "Settings" derive macro reusable from other crates.
- Extend the "Settings" derive macro to generate code for
  InstallSettings and NetworkSettings.
- Improve error reporting when working with the "config"
  subcommand.
* Wed Aug  2 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 3
* Wed Jul 26 2023 Josef Reidinger <jreidinger@suse.com>
- CLI: add to "questions" command "answers" subcommand to set
  file with predefined answers
- dbus-server: add "AddAnswersFile" method to Questions service
  (gh#openSUSE/agama#669)
* Tue Jul 18 2023 Josef Reidinger <jreidinger@suse.com>
- Add to CLI "questions" subcommand with mode option to set
  interactive and non-interactive mode (gh#openSUSE/agama#668)
* Mon Jul 17 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix the logic to decide which network connections to write
  due to a bug introduced in gh#openSUSE/agama#662
  (gh#openSUSE/agama#667).
* Mon Jul 17 2023 Josef Reidinger <jreidinger@suse.com>
- Adapt to new questions D-Bus API to allow automatic answering of
  questions when requested (gh#openSUSE/agama#637, reverts
  gh#openSUSE/agama#649 as now default option is mandatory)
* Thu Jul 13 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Improve error reporting in the command-line interface
  (gh#openSUSE/agama#659 and gh#openSUSE/agama#660).
* Thu Jul 13 2023 José Iván López González <jlopez@suse.com>
- Read the storage candidate devices and show them with
  "agama config show" (gh#openSUSE/agama#658).
* Fri Jul  7 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Improve the progress reporting (gh#openSUSE/agama#653).
* Thu Jul  6 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Improve the waiting logic and implement a retry mechanism for the
  "agama install" command (bsc#1213047).
* Wed Jul  5 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix the questions service to handle questions with no default
  option (gh#openSUSE/agama#649).
* Thu Jun  1 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add a localization D-Bus service (gh#openSUSE/agama#533).
- Add a network D-Bus service (gh#openSUSE/agama#571).
* Tue May 23 2023 Martin Vidner <mvidner@suse.com>
- Version 2.1
* Mon May 22 2023 Martin Vidner <mvidner@suse.com>
- Version 2
* Thu May 11 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Import root authentication settings when reading a Jsonnet file
  (bsc#1211300, gh#openSUSE/agama#573).
- Do not export the SSH public key as an empty string when it is
  not defined.
* Fri Mar 24 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Version 0.2:
  * Add validation for software and users settings
    (gh#yast/agama-cli#48, gh#yast/agama-cli#51).
  * Better error reporting when the bus is not found
    (gh#yast/agama-cli#48).
  * Improve the progress reporting mechanism, although it is still
    a work in progress (gh#yast/agama-cli#50).
* Wed Mar 22 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for setting root authentication mechanisms
  (gh#yast/agama-cli#47).
* Tue Mar 21 2023 Martin Vidner <mvidner@suse.com>
- Do not fall back to the system D-Bus (gh#yast/agama-cli#45).
* Tue Mar 21 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use JSON as the default format (gh#yast/agama-cli#46).
* Tue Mar 21 2023 Josef Reidinger <jreidinger@suse.com>
- Fix the path of the JSON schema (gh#yast/agama-cli#44).
* Thu Mar 16 2023 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- First version of the package:
  * Querying and setting simple values.
  * Adding elements to collections
  * Handling of auto-installation profiles.
  * Basic error handling
- 0.1
